function [kg f] = Restrict(kg, f, nData)
% This function imposes the restraints on the global stiffness matrix and
% the force vector

% How may nodes are there?
[nn ~] = size(nData);

% Store each restrained DOF in a vector
RestrainedDOFs = zeros(2*nn,1);

% For each node, store if there is a restraint
for i = 1:nn
    % x-direction
    if nData(i,5) ~= 0  % if there is a non-zero entry (i.e. supported)
        RestrainedDOFs(2*i-1) = 1;
    end
    % y-direction
    if nData(i,6) ~= 0  % if there is a support
        RestrainedDOFs(2*i) = 1;
    end
end

% for each DOF
for i = 1:2*nn
    if RestrainedDOFs(i) == 1   % if it is restrained
        f(i) = 0;               % Ensure force zero at this DOF
        kg(i,:) = 0;            % make entire row zero
        kg(:,i) = 0;            % make entire column zero
        kg(i,i) = 1;            % put 1 on the diagonal
    end
end